package net.jaekl.cfb.analyze;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;

import net.jaekl.cfb.CfbBundle;
import net.jaekl.cfb.Config;
import net.jaekl.qd.util.MailException;
import net.jaekl.qd.util.MimePart;
import net.jaekl.qd.util.SendMail;

public class Notifier {
	private static final String TEXT_HTML = "text/html";
	
	CfbBundle m_bundle;
	Config m_config;

	public Notifier(CfbBundle bundle, Config config) {
		m_bundle = bundle;
		m_config = config;
	}
	
	public void sendEmailIfNeeded(PrintWriter pw, HtmlReport report) {
		Delta delta = report.getDelta();
		if ((delta.getNumNew() > 0) || (delta.getNumFixed() > 0)) {
			sendEmail(pw, report);
		}
	}
	
	void sendEmail(PrintWriter pw, HtmlReport report) {
		SendMail sendMail = new SendMail();
		
		sendMail.setSmtpHost(m_config.getMailSmtpHost());
		
		ArrayList<String> recipients = m_config.getNotify();
		if (recipients.size() < 1) {
			return;
		}
		
		PrintWriter mailWriter = null;
		
		try {
			String earlier = report.getDelta().getEarlier().constructVersionText(m_bundle);
			String later   = report.getDelta().getLater().constructVersionText(m_bundle);

			sendMail.setFrom(m_config.getMailFrom());
			sendMail.setSubject(m_bundle.get(CfbBundle.CFB_MAIL_SUBJECT, earlier, later));
			
			for (String recipient : recipients) {
				sendMail.addTo(recipient);
			}
			
			StringWriter sw = new StringWriter();
			mailWriter = new PrintWriter(sw);
			report.write(mailWriter);
			mailWriter.flush();

			MimePart part = new MimePart(sw.toString(), TEXT_HTML);
			sendMail.addPart(part);
			sendMail.send();
		}
		catch (MailException exc) {
			StringBuilder toList = new StringBuilder();
			for (String recipient : recipients) {
				if (toList.length() > 0) {
					toList.append(", ");
				}
				toList.append(recipient);
			}
			pw.println(m_bundle.get(CfbBundle.CANNOT_SEND_MAIL, toList.toString(), exc.toString()));
			exc.printStackTrace(pw);
		}
		finally {
			if (null != mailWriter) {
				mailWriter.close();
			}
		}
	}
}
