package net.jaekl.cfb.db.driver;

// Copyright (C) 2015 Christian Jaekl

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.Properties;

import net.jaekl.cfb.db.Sequence;
import net.jaekl.cfb.db.Column.Type;

public class PostgresqlDriver extends DbDriver {

	@Override
	public void load() throws ClassNotFoundException {
		// This should no longer be necessary, so long as we're using 
		// JDBC 4 (which came out with JDK 6) and an updated driver.
		// But, it shouldn't hurt, either.
		Class.forName("org.postgresql.Driver");
	}

	@Override
	public Connection connect(String host, int port, String dbName, String user, String pass) throws SQLException {
		String url = "jdbc:postgresql://" + host + ":" + port + "/" + dbName;
		Properties props = new Properties();
		props.setProperty("user", user);
		props.setProperty("password", pass);
		//props.setProperty("ssl", "true");
		return DriverManager.getConnection(url, props);
	}
	
	@Override 
	public String nextValSql(Sequence seq) 
	{
		return " SELECT NEXTVAL('" + seq.getName() + "') ";
	}
	
	@Override
	protected String typeName(Type type) {
		// Special case:  TIMESTAMPTZ stored as INTEGER (milliseconds since the epoch)
		// Reading a TIMESTAMPTZ back from the DB, and converting it to a java.util.Date,
		// is fraught with peril.  The best way around this is to store the dates in 
		// milliseconds-since-the-epoch (01.01.1970 00:00:00.000 UTC).
		if (Type.TIMESTAMPTZ.equals(type)) {
			return "BIGINT";
		}
		
		return type.toString();
	}}
